@@ -336,7 +336,6 @@ void initJournyDetails(DetailInfo *details, AppData *data) {
 		return;
 	}
 
-
 	/* Create the Subview for details */
 	data->detailsWindow = HILDON_WINDOW(hildon_stackable_window_new());
 	gtk_window_set_title(GTK_WINDOW (data->detailsWindow),
@@ -352,8 +351,16 @@ void initJournyDetails(DetailInfo *details, AppData *data) {
 
     hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA (data->currentDetailsPannableArea), GTK_WIDGET (data->currentDetailsMainVbox));
 
+    /* check, if request comes from gps data it occures that data is empty.*/
+    if (!details->departureStr) {
+
+		hildon_banner_show_information(GTK_WIDGET(data->journeyWindow), NULL,
+						_("Error with received data, please try again"));
+		return;
+    }
+
     /* Journy Details Header */
-	char infoLabel[1000] = "";
+	char infoLabel[2000] = "";
 
 	strcat(infoLabel, "<b>");
 	strcat(infoLabel, details->departureStr);
