@@ -45,14 +45,14 @@ GArray * getStationsByName_mobilebahnde(gchar * stationName) {
 
 	/*
 	g_debug("CURL: %s\n", result);
-	*/
+	 */
 
 	GArray *garray;
 
 	garray = g_array_new (TRUE, TRUE, sizeof (gchar *));
 
 	char *selectBoxFrom = strstr(result,
-			"<select class=\"tpLocList\" name=\"REQ0JourneyStopsS0K\">");
+			"<select name=\"REQ0JourneyStopsS0K\" class=\"nofullwidth\">");
 
 	/* more than one result found */
 	if (selectBoxFrom) {
@@ -155,15 +155,13 @@ GArray * getStationsByGPS_mobilebahnde(gint longitude, gint latitude) {
 
 	if (dataBoxFrom) {
 
-		char *dataBoxTo = strstr(dataBoxFrom, "<p class=\"prio2links\"");
+		char *dataBoxTo = strstr(dataBoxFrom, "<div class=\"bline\">");
 		int count = dataBoxTo - dataBoxFrom;
 		char dataBox[count + 6];
 		strncpy(dataBox, dataBoxFrom, count);
 
 		dataBox[count] = '\0';
 
-		strcat(dataBox, "</div>");
-
 		/*
 		g_debug("DATA %s", dataBox);
 		*/
@@ -253,13 +251,14 @@ ResultInfo * getJourneyData_mobilebahnde(gchar *fromStation, gchar *viaStation,
 		return NULL;
 	}
 
+	/* g_debug(result); */
+
 	/* check if we get a stupid selectbox again so we must resend with ids */
 
 	char *selectBoxFrom = strstr(result,
-			"<select class=\"tpLocList\" name=\"REQ0JourneyStopsS0K\">");
+			"<select name=\"REQ0JourneyStopsS0K\" class=\"nofullwidth\">");
 	char *selectBoxTo = strstr(result,
-			"<select class=\"tpLocList\" name=\"REQ0JourneyStopsZ0K\">");
-
+			"<select name=\"REQ0JourneyStopsZ0K\" class=\"nofullwidth\">");
 	/* more than one result found */
 	if (selectBoxFrom || selectBoxTo) {
 
@@ -387,6 +386,10 @@ DetailInfo * mobilebahnde_parseSearchDetails(gchar *returnData) {
 
 	GArray *garray;
 
+	g_debug(returnData);
+
+	g_debug("DETAILS");
+
 	garray = g_array_new (TRUE, TRUE, sizeof (DetailItem *));
 
 	char *detailsFrom =
@@ -394,7 +397,7 @@ DetailInfo * mobilebahnde_parseSearchDetails(gchar *returnData) {
 
 	if (detailsFrom) {
 
-		char *detailsTo = strstr(detailsFrom, "</div>");
+		char *detailsTo = strstr(detailsFrom, "</div>\n<div id=\"footer\">");
 		int count = detailsTo - detailsFrom + 6;
 		char detailsData[count];
 		strncpy(detailsData, detailsFrom, count);
@@ -421,215 +424,232 @@ DetailInfo * mobilebahnde_parseSearchDetails(gchar *returnData) {
 		xmlNode *sub_node;
 		xmlNode *sub_node2;
 
+		char *durationStr = "";
+		char *departureStr = "";
+		char *arrivalStr = "";
+		char *infoStr = "";
+		char *pricingStr = "";
+
 		for (cur_node = root_element->children; cur_node; cur_node
 				= cur_node->next) {
-			if (!strcmp(cur_node->name, "p")) {
+			if (!strcmp(cur_node->name, "div")) {
 
-				if (!strcmp(cur_node->properties->children->content, "details")) {
+				if (!strcmp(cur_node->properties->children->content, "haupt rline")) {
 
-					/*
-					 * 1. span class="bold" (from)
-					 * 2. a->span (train number)
-					 * 3. text (time and stage)
-					 * 4. span class="red" (error message optional)
-					 * 5. span class="bold" (to)
-					 * 6. text (time and stage)
-					 */
+					/* if first item is a span than its train info */
+					if (!strcmp(cur_node->children->next->name, "span")) {
 
-					char *fromStr = "";
-					char *trainStr = "";
-					char *timeFromStr = "";
-					char *infoStr = "";
-					char *toStr = "";
-					char *timeToStr = "";
-					char *alternateStr = "";
+						g_debug("an item");
+						/*
+						 * 1. span class="bold" (from)
+						 * 2. a->span (train number)
+						 * 3. text (time and stage)
+						 * 4. span class="red" (error message optional)
+						 * 5. span class="bold" (to)
+						 * 6. text (time and stage)
+						 */
+
+						char *fromStr = "";
+						char *trainStr = "";
+						char *timeFromStr = "";
+						char *infoStr = "";
+						char *toStr = "";
+						char *timeToStr = "";
+						char *alternateStr = "";
+
+						for (sub_node = cur_node->children; sub_node; sub_node
+										= sub_node->next) {
+
+							if (!strcmp(sub_node->name, "span")) {
+
+								if (!strcmp(sub_node->properties->children->content, "red")) {
+
+									infoStr = sub_node->children->content;
+								} else if (!strcmp(sub_node->properties->name, "class")) {
+
+									if (strcmp(fromStr, "") && !strcmp(toStr, "")) {
+
+										toStr = sub_node->children->content;
+									}
+									if (!strcmp(fromStr, "") && !strcmp(toStr, "")) {
+
+										fromStr = sub_node->children->content;
+									}
+								}
+							}
+
+
+							if (!strcmp(sub_node->name, "a") && !strcmp(trainStr, "")) {
+
+								for (sub_node2 = sub_node->children; sub_node2; sub_node2
+																		= sub_node2->next) {
+
+									if (!strcmp(sub_node2->name, "span") && !strcmp(trainStr, "")) {
+
+										trainStr = sub_node2->children->content;
+										trainStr = stringReplace(trainStr, "     ", " ");
+									}
+								}
+							}
+
+							if (!strcmp(sub_node->name, "text")) {
+
+								if (strcmp(sub_node->content, "") && strcmp(sub_node->content, "\n")) {
+
+									int  found = 0;
+									char *testFrom = strstr(sub_node->content, "ab ");
+
+									if (testFrom) {
+
+										timeFromStr = testFrom;
+										timeFromStr += 3;
+										found = 1;
+										/* test if next element is a span */
+										sub_node2 = sub_node->next;
+										if (!strcmp(sub_node2->name, "span")) {
+
+											strcat(timeFromStr, sub_node2->children->content);
+											sub_node2 = sub_node2->next;
+											if (!strcmp(sub_node2->name, "text")) {
+
+												strcat(timeFromStr, sub_node2->content);
+												sub_node = sub_node->next;
+												sub_node = sub_node->next;
+											}
+										}
+									}
+									char *testTo = strstr(sub_node->content, "an ");
+
+									if (testTo) {
+
+										timeToStr = testTo;
+										timeToStr += 3;
+										found = 1;
+										/* test if next element is a span */
+										sub_node2 = sub_node->next;
+										if (!strcmp(sub_node2->name, "span")) {
+
+											strcat(timeToStr, sub_node2->children->content);
+											sub_node2 = sub_node2->next;
+											if (!strcmp(sub_node2->name, "text")) {
+
+												strcat(timeToStr, sub_node2->content);
+												sub_node = sub_node->next;
+												sub_node = sub_node->next;
+											}
+										}
+									}
+
+									if (found == 0) {
+
+										alternateStr = sub_node->content;
+										alternateStr += 1;
+									}
+
+								}
+							}
+						}
+
+						DetailItem *detailItem;
+
+						detailItem = g_new0 (DetailItem, 1);
+
+						removeLineBreaks(fromStr);
+						removeLineBreaks(timeFromStr);
+						removeLineBreaks(toStr);
+						removeLineBreaks(timeToStr);
+						removeLineBreaks(trainStr);
+						removeLineBreaks(infoStr);
+						removeLineBreaks(alternateStr);
+
+						detailItem->fromStr = g_strdup_printf(fromStr);
+						detailItem->timeFromStr = g_strdup_printf(timeFromStr);
+						detailItem->toStr = g_strdup_printf(toStr);
+						detailItem->timeToStr = g_strdup_printf(timeToStr);
+						detailItem->trainStr = g_strdup_printf(trainStr);
+						detailItem->infoStr = g_strdup_printf(infoStr);
+						detailItem->alternateStr = g_strdup_printf(alternateStr);
+
+						g_array_append_val (garray, detailItem);
+					} else {
+
+						for (sub_node = cur_node->children; sub_node; sub_node
+										= sub_node->next) {
+
+							if (!strcmp(sub_node->name, "text")) {
+
+								char *testFrom = strstr(sub_node->content, "Dauer:");
+								if (testFrom) {
+
+									testFrom += 7;
+									durationStr = testFrom;
+								}
+
+								testFrom = strstr(sub_node->content, "Hinweis:");
+								if (testFrom) {
+
+									testFrom += 9;
+									infoStr = testFrom;
+								}
+							}
+						}
+					}
+				}
+				if (!strcmp(cur_node->properties->children->content, "haupt")) {
+
+					g_debug("OTHER");
+
+					int counter = 0;
 
 					for (sub_node = cur_node->children; sub_node; sub_node
 									= sub_node->next) {
 
-						if (!strcmp(sub_node->name, "span")) {
-
-							if (!strcmp(sub_node->properties->children->content, "red")) {
-
-								infoStr = sub_node->children->content;
-							} else if (!strcmp(sub_node->properties->name, "class")) {
-
-								if (strcmp(fromStr, "") && !strcmp(toStr, "")) {
-
-									toStr = sub_node->children->content;
-								}
-								if (!strcmp(fromStr, "") && !strcmp(toStr, "")) {
-
-									fromStr = sub_node->children->content;
-								}
-							}
-						}
-
-
-						if (!strcmp(sub_node->name, "a") && !strcmp(trainStr, "")) {
-
-							for (sub_node2 = sub_node->children; sub_node2; sub_node2
-																	= sub_node2->next) {
-
-								if (!strcmp(sub_node2->name, "span") && !strcmp(trainStr, "")) {
-
-									trainStr = sub_node2->children->content;
-									trainStr = stringReplace(trainStr, "     ", " ");
-								}
-							}
-						}
-
 						if (!strcmp(sub_node->name, "text")) {
 
-							if (strcmp(sub_node->content, "") && strcmp(sub_node->content, "\n")) {
+							if (counter == 1) {
 
-								int  found = 0;
-								char *testFrom = strstr(sub_node->content, "ab ");
+								char *testFrom = strstr(sub_node->content, "-");
 
 								if (testFrom) {
 
-									timeFromStr = testFrom;
-									timeFromStr += 3;
-									found = 1;
-									/* test if next element is a span */
-									sub_node2 = sub_node->next;
-									if (!strcmp(sub_node2->name, "span")) {
-
-										strcat(timeFromStr, sub_node2->children->content);
-										sub_node2 = sub_node2->next;
-										if (!strcmp(sub_node2->name, "text")) {
-
-											strcat(timeFromStr, sub_node2->content);
-											sub_node = sub_node->next;
-											sub_node = sub_node->next;
-										}
-									}
+									int count = strlen(sub_node->content) - strlen(testFrom) - 2;
+									char departureStr2[count];
+									strncpy(departureStr2 , sub_node->content + 1, count);
+									departureStr2[count] = '\0';
+									departureStr = g_strdup_printf(departureStr2);
+									arrivalStr   = testFrom;
+									arrivalStr  += 1;
 								}
-								char *testTo = strstr(sub_node->content, "an ");
+							}
 
-								if (testTo) {
-
-									timeToStr = testTo;
-									timeToStr += 3;
-									found = 1;
-									/* test if next element is a span */
-									sub_node2 = sub_node->next;
-									if (!strcmp(sub_node2->name, "span")) {
-
-										strcat(timeToStr, sub_node2->children->content);
-										sub_node2 = sub_node2->next;
-										if (!strcmp(sub_node2->name, "text")) {
-
-											strcat(timeToStr, sub_node2->content);
-											sub_node = sub_node->next;
-											sub_node = sub_node->next;
-										}
-									}
-								}
-
-								if (found == 0) {
-
-									alternateStr = sub_node->content;
-									alternateStr += 1;
-								}
+							if (counter == 0) {
 
+								pricingStr = sub_node->content + 1;
+								counter++;
 							}
 						}
 					}
-
-					DetailItem *detailItem;
-
-					detailItem = g_new0 (DetailItem, 1);
-
-					removeLineBreaks(fromStr);
-					removeLineBreaks(timeFromStr);
-					removeLineBreaks(toStr);
-					removeLineBreaks(timeToStr);
-					removeLineBreaks(trainStr);
-					removeLineBreaks(infoStr);
-					removeLineBreaks(alternateStr);
-
-					detailItem->fromStr = g_strdup_printf(fromStr);
-					detailItem->timeFromStr = g_strdup_printf(timeFromStr);
-					detailItem->toStr = g_strdup_printf(toStr);
-					detailItem->timeToStr = g_strdup_printf(timeToStr);
-					detailItem->trainStr = g_strdup_printf(trainStr);
-					detailItem->infoStr = g_strdup_printf(infoStr);
-					detailItem->alternateStr = g_strdup_printf(alternateStr);
-
-					g_array_append_val (garray, detailItem);
-				}
-				if (!strcmp(cur_node->properties->children->content, "connectiondetails")) {
-
-					/*
-					 * 1. text starts with "Abfahrt:" (departure)
-					 * 2. text starts with "Ankunft:" (arrival)
-					 * 3. text starts with "Dauer:" (duration)
-					 * 4. text stats with "Hinweis:" (info optional)
-					 * 5. span class="bold" (pricing infos)
-					 */
-
-					char *departureStr = "";
-					char *arrivalStr = "";
-					char *durationStr = "";
-					char *infoStr = "";
-					char *pricingStr = "";
-
-					for (sub_node = cur_node->children; sub_node; sub_node
-									= sub_node->next) {
-
-						if (!strcmp(sub_node->name, "text")) {
-
-							char *testFrom = strstr(sub_node->content, "Abfahrt:");
-							if (testFrom) {
-
-								testFrom += 9;
-								departureStr = testFrom;
-							}
-							testFrom = strstr(sub_node->content, "Ankunft:");
-							if (testFrom) {
-
-								testFrom += 9;
-								arrivalStr = testFrom;
-							}
-							testFrom = strstr(sub_node->content, "Dauer:");
-							if (testFrom) {
-
-								testFrom += 7;
-								durationStr = testFrom;
-							}
-							testFrom = strstr(sub_node->content, "Hinweis:");
-							if (testFrom) {
-
-								testFrom += 9;
-								infoStr = testFrom;
-							}
-						}
-
-						if (!strcmp(sub_node->name, "span")) {
-
-							pricingStr = sub_node->children->content;
-							pricingStr += 1;
-						}
-					}
-
-					removeLineBreaks(departureStr);
-					removeLineBreaks(arrivalStr);
-					removeLineBreaks(durationStr);
-					removeLineBreaks(infoStr);
-					removeLineBreaks(pricingStr);
-
-					detailInfo->arrivalStr = g_strdup_printf(arrivalStr);
-					detailInfo->departureStr = g_strdup_printf(departureStr);
-					detailInfo->durationStr = g_strdup_printf(durationStr);
-					detailInfo->infoStr = g_strdup_printf(infoStr);
-					detailInfo->pricingStr = g_strdup_printf(pricingStr);
 				}
 			}
 		}
+
+		removeLineBreaks(departureStr);
+		removeLineBreaks(arrivalStr);
+		removeLineBreaks(infoStr);
+		removeLineBreaks(pricingStr);
+		removeLineBreaks(durationStr);
+
+		detailInfo->arrivalStr = g_strdup_printf(arrivalStr);
+		detailInfo->departureStr = g_strdup_printf(departureStr);
+		detailInfo->infoStr = g_strdup_printf(infoStr);
+		detailInfo->pricingStr = g_strdup_printf(pricingStr);
+		detailInfo->durationStr = g_strdup_printf(durationStr);
 	}
 
+	g_debug("end");
+
 	detailInfo->items = garray;
+
 	return detailInfo;
 }
 
@@ -671,12 +691,12 @@ ResultInfo * mobilebahnde_parseSearchResult(gchar *returnData) {
 
 	/* GET HEADER */
 
-	char *headerDataFrom = strstr(returnData, "<p class=\"qs\">");
+	char *headerDataFrom = strstr(returnData, "<div class=\"haupt\">");
 
 	if (headerDataFrom) {
 
-		char *headerDataTo = strstr(headerDataFrom, "</p>");
-		int count = headerDataTo - headerDataFrom + 4;
+		char *headerDataTo = strstr(headerDataFrom, "</div>");
+		int count = headerDataTo - headerDataFrom + 6;
 		char headerData[count];
 		strncpy(headerData, headerDataFrom, count);
 
@@ -729,12 +749,12 @@ ResultInfo * mobilebahnde_parseSearchResult(gchar *returnData) {
 	/* later and earlier buttons */
 
 	char *resultButtonsFrom =
-				strstr(returnData, "<div id=\"content\">");
+				strstr(returnData, "<ul class=\"neben\">");
 
 	if (resultButtonsFrom) {
 
-		char *resultButtonsTo = strstr(resultButtonsFrom, "</div>");
-		int count = resultButtonsTo - resultButtonsFrom + 6;
+		char *resultButtonsTo = strstr(resultButtonsFrom, "</ul>");
+		int count = resultButtonsTo - resultButtonsFrom + 5;
 		char resultButtons[count];
 		strncpy(resultButtons, resultButtonsFrom, count);
 
@@ -764,7 +784,7 @@ ResultInfo * mobilebahnde_parseSearchResult(gchar *returnData) {
 
 		for (cur_node = root_element->children; cur_node; cur_node
 				= cur_node->next) {
-			if (!strcmp(cur_node->name, "p")) {
+			if (!strcmp(cur_node->name, "li")) {
 
 				for (sub_node = cur_node->children; sub_node; sub_node
 								= sub_node->next) {
@@ -798,10 +818,12 @@ ResultInfo * mobilebahnde_parseSearchResult(gchar *returnData) {
 	}
 
 
+	g_debug("meeep");
+
 	/* RESULTS ITSELF */
 
 	char *resultDataFrom =
-			strstr(returnData, "<table class=\"ovTable\">");
+			strstr(returnData, "<table class=\"ovTable clicktable\">");
 
 	if (resultDataFrom) {
 
@@ -934,6 +956,25 @@ GArray * mobilebahnde_getResultValues(xmlNode * a_node) {
 
 							resultItem->changeStr = g_strdup_printf(sub_node->children->content);
 						}
+
+						int counter = 0;
+
+						for (tmp_node = sub_node->children; tmp_node; tmp_node
+								= tmp_node->next) {
+
+							if (counter == 1 && !strcmp(tmp_node->name, "text")) {
+
+								resultItem->durationStr = g_strdup_printf(tmp_node->content);
+								counter++;
+							}
+
+							if (counter == 0 && !strcmp(tmp_node->name, "text")) {
+
+								resultItem->changeStr = g_strdup_printf(tmp_node->content);
+								counter++;
+							}
+						}
+
 						break;
 					case 3:
 
