@@ -43,7 +43,7 @@
 #include <curl/curl.h>
 
 #define APP_NAME "fahrplan"
-#define APP_VER "0.0.8"
+#define APP_VER "0.0.8-1"
 #define APP_SERVICE "com.nokia.fahrplan"
 #define APP_METHOD "/com/nokia/fahrplan"
 
@@ -77,6 +77,7 @@ struct _ResultItem {
 	gchar *fromTimeStr;
 	gchar *toTimeStr;
 	gchar *trainTypeStr;
+	gchar *durationStr;
 	gchar *changeStr;
 	gchar *warningStr;
 	gchar *detailsUrl;
